/** 内存的容量常量定义 */
export declare enum MemorySize {
    /** 1K字节数 1024 */
    K = 1024,
    /** 1M字节数 1048576 */
    M = 1048576,
    /** 1G字节数 1073741824 */
    G = 1073741824,
    /** 1T字节数 1099511627776 */
    T = 1099511627776,
    /** 1P字节数 */
    P = 1125899906842624
}
/** 默认的错误码 */
export declare enum error_common {
    /** 正确 */
    ERR_OK = 0,
    /** 失败 */
    ERR_FAIL = -1,
    /** 表示返回true */
    ERR_TRUE = -2,
    /** 表示返回false */
    ERR_FALSE = -3
}
/**
 * 日期时间的常量
 */
export declare enum DatetimeConstant {
    /** 最小的UTC时间 */
    MIN_UTC = 1,
    /** 最大的UTC时间 */
    MAX_UTC = 253370736000000,
    /** 无效的UTC时间 */
    INVALID_UTC = 0,
    /** 每天最大的毫少数 */
    MILLIS_PRE_DAY = 86400000,
    /** 每分钟的秒数 */
    SECOND_PRE_MINUTE = 60,
    /** 每秒的毫秒数 */
    MILLIS_PRE_SECOND = 1000,
    /** 公元元年到1970-01-01的天数 */
    DAYS_1970 = 719528
}
/** 是或否 */
export declare enum YesOrNo {
    yes = 1,
    no = 0
}
/**
 * 选项类型
 */
export declare type TOptions<T> = {
    [P in keyof T]?: NonNullable<any>;
};
/** 通用正则表达式 */
export declare const CommonReg: {
    /** YYYY-MM-DD hh:mm:ss 格式的正则表达式 */
    dateTime: RegExp;
    /** 货币类正则表达式 */
    curreny: RegExp;
    /** 货币千分位 */
    curreny_thousandth: RegExp;
    /** YYYY-MM-DD 支持 . - / \ 空格分隔符 格式 */
    baseDate: RegExp;
    /** 范围日期
     * - 不支持空格做为日期的分隔符，因为需要用它做前后两个日期的分隔符
     */
    baseRangeDate: RegExp;
    /** YYYYMMDD 格式的日期正则表达式 */
    simpleDate: RegExp;
    /** hh:mm:ss的正则表达式 */
    baseTime: RegExp;
    /** hhmmss的正则表达式 */
    simpleTime: RegExp;
    /** 仅数字 */
    onlyDigit: RegExp;
    /** 仅小写字母 */
    onlyLowercase: RegExp;
    /** 仅大写字母 */
    onlyCapitalLetter: RegExp;
    /** 仅大小写字母 */
    onlyLetter: RegExp;
    /** 数字与大小写字母 */
    digitOrLetter: RegExp;
    /** 15位身份证 */
    idNumber15: RegExp;
    /** 18位身份证 */
    idNumber18: RegExp;
    /** email地址 */
    email: RegExp;
    /** ascii字符 */
    ascii: RegExp;
    /** 字母是大写的16进制 */
    uppercaseHEX: RegExp;
    /** 字母是小写的16进制 */
    lowercaseHEX: RegExp;
    /** url */
    url: RegExp;
    /** 整数 */
    integer: RegExp;
    /** 数字 */
    decimal: RegExp;
    /** 中国手机号 xxxxxxxxxxx */
    mobile_cn_none: RegExp;
    /** 中国手机号 xxx-xxxx-xxxx */
    mobile_cn_344: RegExp;
    /** 中国手机号 xxx-xxx-xxxxx */
    mobile_cn_335: RegExp;
    /** 中国手机号 xxxx-xxxx-xxx */
    mobile_cn_443: RegExp;
    /** 国外手机号 */
    mobile_other: RegExp;
};
